@@ -15,7 +15,7 @@
 /*
  * John's version number.
  */
-#define JOHN_VERSION			"1.6.39"
+#define JOHN_VERSION			"1.6.40"
 
 /*
  * Is this a system-wide installation? *BSD ports and Linux distributions
@@ -26,23 +26,30 @@
 #endif
 
 #if JOHN_SYSTEMWIDE
+#ifndef JOHN_SYSTEMWIDE_EXEC
 #define JOHN_SYSTEMWIDE_EXEC		"/usr/libexec/john"
+#endif
+#ifndef JOHN_SYSTEMWIDE_HOME
 #define JOHN_SYSTEMWIDE_HOME		"/usr/share/john"
+#endif
 #define JOHN_PRIVATE_HOME		"~/.john"
 #endif
 
 /*
  * Crash recovery file format version strings.
  */
-#define RECOVERY_VERSION_0		"REC0"
-#define RECOVERY_VERSION_1		"REC1"
-#define RECOVERY_VERSION_2		"REC2"
-#define RECOVERY_VERSION_CURRENT	RECOVERY_VERSION_2
+#define RECOVERY_V0			"REC0"
+#define RECOVERY_V1			"REC1"
+#define RECOVERY_V2			"REC2"
+#define RECOVERY_V3			"REC3"
+#define RECOVERY_V			RECOVERY_V3
 
 /*
  * Charset file format version string.
  */
-#define CHARSET_VERSION			"CHR1"
+#define CHARSET_V1			"CHR1"
+#define CHARSET_V2			"CHR2"
+#define CHARSET_V			CHARSET_V2
 
 /*
  * Timer interval in seconds.
@@ -119,7 +126,7 @@ extern int password_hash_thresholds[3];
 /*
  * Cracked password hash size, used while loading.
  */
-#define CRACKED_HASH_LOG		10
+#define CRACKED_HASH_LOG		11
 #define CRACKED_HASH_SIZE		(1 << CRACKED_HASH_LOG)
 
 /*
